@@ -24,8 +24,8 @@ L<Astro::Coord::ECI|Astro::Coord::ECI> coordinate-transformation code.
 As of version 0.104 these warn on the first use, as will the first
 attempt to call C<equation_of_time()> and C<obliquity()> as a subroutine
 (i.e. with a first argument that looks like a number). As of version
-0.109 release after September 1 2019 all calls will result in a warning.
-As of the first release after December 1 2019 all calls will be fatal.
+0.109 all calls will result in a warning. As of version 0.113 all calls
+will be fatal.
 
 =head1 DESCRIPTION
 
@@ -142,7 +142,7 @@ package Astro::Coord::ECI::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '0.111_02';
+our $VERSION = '0.112_01';
 our @ISA = qw{Exporter};
 
 use Carp;
@@ -704,6 +704,7 @@ Chapter 28, page 185.
 
 This subroutine is deprecated in favor of the
 L<Astro::Coord::ECI|Astro::Coord::ECI> C<equation_of_time()> method.
+As of version C<0.113> it produces a fatal error.
 
 =cut
 
@@ -1141,6 +1142,7 @@ Edition, Chapter 22, pages 143ff. Meeus states that it is good to
 
 This subroutine is deprecated in favor of the
 L<Astro::Coord::ECI|Astro::Coord::ECI> C<nutation()> method.
+As of version C<0.113> it produces a fatal error.
 
 =cut
 
@@ -1174,6 +1176,7 @@ Edition, Chapter 22, pages 143ff. Meeus states that it is good to
 
 This subroutine is deprecated in favor of the
 L<Astro::Coord::ECI|Astro::Coord::ECI> C<nutation()> method.
+As of version C<0.113> it produces a fatal error.
 
 =cut
 
@@ -1207,6 +1210,7 @@ dynamical time comes from chapter 10, equation 10.2  on page 78.
 
 This subroutine is deprecated in favor of the
 L<Astro::Coord::ECI|Astro::Coord::ECI> C<obliquity()> method.
+As of version C<0.113> it produces a fatal error.
 
 =cut
 
@@ -1647,56 +1651,29 @@ sub __instance {
 
 }
 
-{
-    # The following ugliness is because in 5.21.2 P5P decided to
-    # introduce a new warnings category, 'redundant' and have sprintf
-    # log that warning if the template did not use all arguments. The
-    # following is to my mind the least bad way to restore the old
-    # behavior. The rejected alternatives were:
-    # * Disable all warnings
-    #   This prohibits possible other warnings from being reported
-    # * Install a $SIG{__WARN__} hook
-    #   I would either have to quash all warnings (giving the above
-    #   behavior with its problems plus a run-time penalty) or analyze
-    #   the warning and decide what to do with it (fragile, since I know
-    #   of no contract not to change warning messages)
-    # * Preprocess the template and truncate the arguments based on
-    #   substitutions found
-    #   This strikes me as complex and fragile, though given the
-    #   template semantics it may be the next-best alternative.
-    #
-    # This mess may end up being exposed, even named as it is, but for
-    # the moment it is private to me.
-    my $no_redundant = $] ge '5.021002' ? 'no warnings qw{ redundant };' : '';
-    eval <<"EOD"	## no critic (ProhibitStringyEval)
-sub __sprintf (\$\@) {
-    my ( \$tplt, \@args ) = \@_;
-    defined \$tplt
-	or return undef;	## no critic (ProhibitReturnUndef)
-    $no_redundant
-    return sprintf \$tplt, \@args;
-}
-
-1
-EOD
-	or die $@;
+sub __sprintf($@) {		## no critic (ProhibitSubroutinePrototypes)
+    my ( $tplt, @args ) = @_;
+    defined $tplt
+	or return undef;	## no critic (ProhibitExplicitReturnUndef)
+    no if $] gt '5.021002', qw{ warnings redundant };
+    return sprintf $tplt, @args;
 }
 
 {
     my %deprecate = (
 	equation_of_time	=> {
-	    level	=> 2,
+	    level	=> 3,
 	},
 	nutation_in_longitude	=> {
-	    level	=> 2,
+	    level	=> 3,
 	    method	=> 'nutation',
 	},
 	nutation_in_obliquity	=> {
-	    level	=> 2,
+	    level	=> 3,
 	    method	=> 'nutation',
 	},
 	obliquity	=> {
-	    level	=> 2,
+	    level	=> 3,
 	},
     );
 
